## tests\integration\data\html\

#### Links

Parent

#### Navigation

Pass | File | Added | Removed | Changes | Reordered | Score | Comments
✖ | all_text_types_3 | 23 | 1 | 0 | 0 | 4 | split_paragraphs
✖ | blockquote | 7 | 1 | 0 | 0 | 4 | false_heading
✖ | blockquote_columns | 8 | 1 | 0 | 0 | 5 |
✖ | columns_with_headers | 21 | 1 | 0 | 0 | 4 | split_paragraphs
✖ | column_switch | 10 | 1 | 0 | 0 | 5 |
✖ | complex_doc | 11 | 1 | 0 | 0 | 5 |
✖ | complex_doc_2 | 11 | 1 | 0 | 0 | 5 |
✖ | complex_fonts | 35 | 1 | 0 | 0 | 5 |
⚠ | drawing_bullets | 9 | 1 | 0 | 0 | 3 | missed_bullets
✖ | duplicate_text | 8 | 1 | 0 | 0 | 5 |
✖ | end_image | 7 | 1 | 0 | 0 | 4 | wrong_order, missed_links
✖ | image_above_text | 9 | 1 | 0 | 0 | 5 | missed_links
✖ | inline_images | 7 | 1 | 0 | 0 | 5 | missed_links
⚠ | inline_simple_tables | 12 | 1 | 0 | 0 | 2 | missed_tables
✖ | lists | 6 | 1 | 0 | 0 | 5 |
⚠ | nested_lists | 11 | 1 | 0 | 0 | 3 | missed_nested_list
⚠ | nested_lists_columns | 41 | 1 | 0 | 0 | 3 | missed_nested_list
⚠ | out_of_line_image | 10 | 1 | 0 | 0 | 2 | missed_tables
⚠ | tables | 22 | 1 | 0 | 0 | 2 | wrong_tables
✖ | three_columns | 24 | 1 | 0 | 0 | 5 |
✖ | three_columns_landscape | 29 | 1 | 0 | 0 | 5 |
✖ | two_columns | 8 | 1 | 0 | 0 | 5 |
✖ | two_paragraphs | 3 | 1 | 0 | 0 | 5 |
✖ | wrapped_images | 9 | 1 | 0 | 0 | 5 |